summaryrefslogtreecommitdiff
path: root/chromium/gpu/command_buffer/client/fenced_allocator.h
diff options
context:
space:
mode:
authorAllan Sandfeld Jensen <allan.jensen@qt.io>2018-10-24 11:30:15 +0200
committerAllan Sandfeld Jensen <allan.jensen@qt.io>2018-10-30 12:56:19 +0000
commit6036726eb981b6c4b42047513b9d3f4ac865daac (patch)
tree673593e70678e7789766d1f732eb51f613a2703b /chromium/gpu/command_buffer/client/fenced_allocator.h
parent466052c4e7c052268fd931888cd58961da94c586 (diff)
downloadqtwebengine-chromium-6036726eb981b6c4b42047513b9d3f4ac865daac.tar.gz
BASELINE: Update Chromium to 70.0.3538.78
Change-Id: Ie634710bf039e26c1957f4ae45e101bd4c434ae7 Reviewed-by: Michael BrĂ¼ning <michael.bruning@qt.io>
Diffstat (limited to 'chromium/gpu/command_buffer/client/fenced_allocator.h')
-rw-r--r--chromium/gpu/command_buffer/client/fenced_allocator.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/chromium/gpu/command_buffer/client/fenced_allocator.h b/chromium/gpu/command_buffer/client/fenced_allocator.h
index 9c42d34ec13..f820ca23f91 100644
--- a/chromium/gpu/command_buffer/client/fenced_allocator.h
+++ b/chromium/gpu/command_buffer/client/fenced_allocator.h
@@ -216,14 +216,15 @@ class FencedAllocatorWrapper {
}
// Gets a pointer to a memory block given the base memory and the offset.
// It translates FencedAllocator::kInvalidOffset to NULL.
void *GetPointer(FencedAllocator::Offset offset) {
- return (offset == FencedAllocator::kInvalidOffset) ?
- NULL : static_cast<char *>(base_) + offset;
+ return (offset == FencedAllocator::kInvalidOffset)
+ ? nullptr
+ : static_cast<char*>(base_) + offset;
}
// Gets the offset to a memory block given the base memory and the address.
// It translates NULL to FencedAllocator::kInvalidOffset.
FencedAllocator::Offset GetOffset(void *pointer) {
return pointer ?
static_cast<FencedAllocator::Offset>(
@@ -216,14 +216,15 @@ class FencedAllocatorWrapper {
}
// Gets a pointer to a memory block given the base memory and the offset.
- // It translates FencedAllocator::kInvalidOffset to NULL.
+ // It translates FencedAllocator::kInvalidOffset to nullptr.
void *GetPointer(FencedAllocator::Offset offset) {
@@ -216,14 +216,15 @@ class FencedAllocatorWrapper {
}
// Gets the offset to a memory block given the base memory and the address.
- // It translates NULL to FencedAllocator::kInvalidOffset.
+ // It translates nullptr to FencedAllocator::kInvalidOffset.
FencedAllocator::Offset GetOffset(void *pointer) {
return pointer ?